@@ -372,6 +372,10 @@ class SubjectDicomCrawler(Crawler):
         file_paths = []
         for root, _, files in os.walk(self.path):
             for file in files:
+
+                if file == 'DICOMDIR':
+                    continue
+
                 file_path = os.path.join(root, file)
                 if is_dicom_file(file_path):
                     file_paths.append(file_path)
@@ -602,7 +606,7 @@ class SubjectDicomCrawler(Crawler):
                                      'This will cause ambiguity when loading the DICOM series. Use either a modality '
                                      'configuration file or a modality extractor to resolve this issue.')
 
-                if config.has_default_modalities() and self.write_config is False:
+                if config.has_default_modalities() and self.write_config is False and len(config.configuration) > 1:
                     raise ValueError('The extracted modalities contain at least one default modality. '
                                      'This will cause ambiguity when loading the DICOM series. Use either a modality '
                                      'configuration file or a modality extractor to resolve this issue.')
@@ -611,6 +615,9 @@ class SubjectDicomCrawler(Crawler):
                     config.to_file(os.path.join(self.path, self.config_file_name))
                     return
 
+                if not config.has_duplicate_modalities():
+                    return
+
                 raise ValueError('The modality configuration file could not be found '
                                  f'in the specified path ({self.path}) and there is no modality extractor provided!')
 
@@ -740,6 +747,9 @@ class DatasetDicomCrawler(Crawler):
 
         for root, _, files in os.walk(path):
             for file in files:
+                if file == 'DICOMDIR':
+                    continue
+
                 file_path = os.path.join(root, file)
 
                 # check if file is a dicom file
