@@ -16,7 +16,7 @@ import numpy as np
 import SimpleITK as sitk
 import itk
 
-from pyradise.data import Subject, TransformInfo, ImageProperties, Image
+from pyradise.data import Subject, TransformInfo, ImageProperties, Image, IntensityImage, SegmentationImage
 
 __all__ = ['FilterParams', 'Filter', 'LoopEntryFilterParams', 'LoopEntryFilter', 'FilterPipeline']
 
@@ -165,7 +165,8 @@ class Filter(ABC):
         >>>
         >>>     def execute_inverse(self,
         >>>                         subject: Subject,
-        >>>                         transform_info: TransformInfo
+        >>>                         transform_info: TransformInfo,
+        >>>                         target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
         >>>                         ) -> Subject:
         >>>         # loop through the images
         >>>         for image in subject.get_images():
@@ -192,11 +193,19 @@ class Filter(ABC):
         >>>
         >>>         return subject
 
+    Args:
+        warning_on_non_invertible (bool): If True, a warning is printed to the console if a filter is called to
+         execute the invertible process but is not invertible (default: False).
 
     """
 
-    def __init__(self):
+    def __init__(self,
+                 warning_on_non_invertible: bool = False
+                 ) -> None:
         super().__init__()
+
+        self.warn_on_non_invertible = warning_on_non_invertible
+
         self.verbose = False
 
         # register here all filter arguments such that the filter can be reconstructed
@@ -226,6 +235,18 @@ class Filter(ABC):
         """
         self.verbose = verbose
 
+    def set_warning_on_non_invertible(self, warn: bool) -> None:
+        """Set the warning state.
+
+        Args:
+            warn (bool): If True, the filter outputs a warning if the filter is called and is not invertible,
+             otherwise not.
+
+        Returns:
+            None
+        """
+        self.warn_on_non_invertible = warn
+
     def _register_tracked_data(self,
                                image: Image,
                                pre_transform_image: Union[sitk.Image, itk.Image],
@@ -283,7 +304,8 @@ class Filter(ABC):
     @abstractmethod
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Execute the filter inversely if possible. Typically, this method gets a temporary subject which contains
         a single image because the recording of the transformations is image dependent and inappropriate inverse
@@ -298,6 +320,9 @@ class Filter(ABC):
         Args:
             subject (Subject): The subject to be processed.
             transform_info (TransformInfo): The :class:`~pyradise.data.taping.TransformInfo` instance.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The processed subject.
@@ -409,7 +434,8 @@ class LoopEntryFilter(Filter):
     @abstractmethod
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Execute the filter inversely if possible. Typically, this method gets a temporary subject which contains
         a single image because the recording of the transformations is image dependent and inappropriate inverse
@@ -424,6 +450,9 @@ class LoopEntryFilter(Filter):
         Args:
             subject (Subject): The subject to be processed.
             transform_info (TransformInfo): The :class:`~pyradise.data.taping.TransformInfo` instance.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The processed subject.
@@ -439,16 +468,20 @@ class FilterPipeline:
     Args:
         filters (Optional[Tuple[Filter, ...]]): The filters of the pipeline (default: None).
         params (Optional[Tuple[FilterParams, ...]]): The parameters for the filters in the pipeline.
+        warning_on_non_invertible (bool): If True, a warning is printed to the console if a filter is called to
+         execute the invertible process but is not invertible (default: False).
     """
 
     def __init__(self,
                  filters: Optional[Tuple[Filter, ...]] = None,
-                 params: Optional[Tuple[FilterParams, ...]] = None
+                 params: Optional[Tuple[FilterParams, ...]] = None,
+                 warning_on_non_invertible: bool = False
                  ) -> None:
         super().__init__()
 
         self.filters: List[Filter, ...] = []
         self.params: List[FilterParams, ...] = []
+        self.warn_on_non_invertible = warning_on_non_invertible
 
         if filters:
             if not params:
@@ -542,6 +575,12 @@ class FilterPipeline:
             if self.logger:
                 self.logger.info(f'{subject.get_name()}: Pipeline executing {filter_.__class__.__name__}...')
 
+            # set the warning on and off
+            if self.warn_on_non_invertible:
+                filter_.set_warning_on_non_invertible(True)
+            else:
+                filter_.set_warning_on_non_invertible(False)
+
             subject = filter_.execute(subject, param)
 
         return subject
