@@ -5,6 +5,7 @@ from typing import (
     Union
 )
 from copy import deepcopy
+import warnings
 
 from pyradise.data import (
     Subject,
@@ -104,7 +105,8 @@ class AddImageFilter(Filter):
 
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Return the provided subject without any processing because the inverse addition procedure (the removal)
         is currently not supported.
@@ -112,10 +114,21 @@ class AddImageFilter(Filter):
         Args:
             subject (Subject): The :class:`~pyradise.data.subject.Subject` instance to be returned.
             transform_info (TransformInfo): The transform information.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The provided :class:`~pyradise.data.subject.Subject` instance.
         """
+
+        # potentially warn the user that the operation is not invertible
+        if self.warn_on_non_invertible and not self.is_invertible():
+            warnings.warn('WARNING: '
+                          f'The {self.__class__.__name__} is called to invert its operation for the following image: \n'
+                          f'\t{target_image.__str__()} \nHowever, the filter is not invertible. The provided subject '
+                          'is returned without modification.')
+
         return subject
 
 
@@ -175,17 +188,29 @@ class RemoveImageByOrganFilter(Filter):
 
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Return the provided subject without any processing because the removal procedure is not invertible.
 
         Args:
             subject (Subject): The :class:`~pyradise.data.subject.Subject` instance to be returned.
             transform_info (TransformInfo): The transform information.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The provided :class:`~pyradise.data.subject.Subject` instance.
         """
+
+        # potentially warn the user that the operation is not invertible
+        if self.warn_on_non_invertible and not self.is_invertible():
+            warnings.warn('WARNING: '
+                          f'The {self.__class__.__name__} is called to invert its operation for the following image: \n'
+                          f'\t{target_image.__str__()} \nHowever, the filter is not invertible. The provided subject '
+                          'is returned without modification.')
+
         return subject
 
 
@@ -246,17 +271,29 @@ class RemoveImageByAnnotatorFilter(Filter):
 
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Return the provided subject without any processing because the removal procedure is not invertible.
 
         Args:
             subject (Subject): The :class:`~pyradise.data.subject.Subject` instance to be returned.
             transform_info (TransformInfo): The transform information.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The provided :class:`~pyradise.data.subject.Subject` instance.
         """
+
+        # potentially warn the user that the operation is not invertible
+        if self.warn_on_non_invertible and not self.is_invertible():
+            warnings.warn('WARNING: '
+                          f'The {self.__class__.__name__} is called to invert its operation for the following image: \n'
+                          f'\t{target_image.__str__()} \nHowever, the filter is not invertible. The provided subject '
+                          'is returned without modification.')
+
         return subject
 
 
@@ -317,17 +354,29 @@ class RemoveImageByModalityFilter(Filter):
 
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Return the provided subject without any processing because the removal procedure is not invertible.
 
         Args:
             subject (Subject): The :class:`~pyradise.data.subject.Subject` instance to be returned.
             transform_info (TransformInfo): The transform information.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+            transformation should be applied. If None, the inverse transformation is applied to all images (default:
+            None).
 
         Returns:
             Subject: The provided :class:`~pyradise.data.subject.Subject` instance.
         """
+
+        # potentially warn the user that the operation is not invertible
+        if self.warn_on_non_invertible and not self.is_invertible():
+            warnings.warn('WARNING: '
+                          f'The {self.__class__.__name__} is called to invert its operation for the following image: \n'
+                          f'\t{target_image.__str__()} \nHowever, the filter is not invertible. The provided subject '
+                          'is returned without modification.')
+
         return subject
 
 
@@ -556,15 +605,27 @@ class MergeSegmentationFilter(Filter):
 
     def execute_inverse(self,
                         subject: Subject,
-                        transform_info: TransformInfo
+                        transform_info: TransformInfo,
+                        target_image: Optional[Union[SegmentationImage, IntensityImage]] = None
                         ) -> Subject:
         """Return the provided subject without any processing because the merging procedure is not invertible.
 
         Args:
             subject (Subject): The :class:`~pyradise.data.subject.Subject` instance to be returned.
             transform_info (TransformInfo): The transform information.
+            target_image (Optional[Union[SegmentationImage, IntensityImage]]): The target image to which the inverse
+             transformation should be applied. If None, the inverse transformation is applied to all images (default:
+             None).
 
         Returns:
             Subject: The provided :class:`~pyradise.data.subject.Subject` instance.
         """
+
+        # potentially warn the user that the operation is not invertible
+        if self.warn_on_non_invertible and not self.is_invertible():
+            warnings.warn('WARNING: '
+                          f'The {self.__class__.__name__} is called to invert its operation for the following image: \n'
+                          f'\t{target_image.__str__()} \nHowever, the filter is not invertible. The provided subject '
+                          'is returned without modification.')
+
         return subject
